@@ -66,9 +66,6 @@ set_vcgt_from_data (cmsHPROFILE profile,
 	return ret;
 }
 
-/**
- * cd_util_create_colprof:
- **/
 static gboolean
 cd_util_create_colprof (CdUtilPrivate *priv,
 			CdDom *dom,
@@ -100,8 +97,10 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 	g_autofree gchar *debug_stdout = NULL;
 	g_autofree gchar *output_fn = NULL;
 	g_autofree gchar *ti3_fn = NULL;
+	g_autofree gchar *tmpdir = NULL;
 	g_autoptr(GFile) output_file = NULL;
 	g_autoptr(GFile) ti3_file = NULL;
+	g_autoptr(GFile) tmpdir_file = NULL;
 	g_autoptr(GPtrArray) argv = NULL;
 
 #ifndef TOOL_COLPROF
@@ -192,8 +191,15 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 				     "XML error: no data_ti3");
 		return FALSE;
 	}
+
+	/* create temp location */
+	tmpdir = g_dir_make_tmp ("cd-create-profile-XXXXXX", error);
+	if (tmpdir == NULL)
+		return FALSE;
+	tmpdir_file = g_file_new_for_path (tmpdir);
+
 	data_ti3 = cd_dom_get_node_data (tmp);
-	ti3_fn = g_strdup_printf ("/tmp/%s.ti3", basename);
+	ti3_fn = g_strdup_printf ("%s/%s.ti3", tmpdir, basename);
 	ti3_file = g_file_new_for_path (ti3_fn);
 	ret = g_file_replace_contents (ti3_file,
 				       data_ti3,
@@ -208,7 +214,7 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 		return FALSE;
 
 	/* ensure temporary icc profile does not already exist */
-	output_fn = g_strdup_printf ("/tmp/%s.icc", basename);
+	output_fn = g_strdup_printf ("%s/%s.icc", tmpdir, basename);
 	output_file = g_file_new_for_path (output_fn);
 	if (g_file_query_exists (output_file, NULL)) {
 		if (!g_file_delete (output_file, NULL, error))
@@ -219,7 +225,7 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 	g_ptr_array_add (argv, g_strdup_printf ("-O%s.icc", basename));
 	g_ptr_array_add (argv, g_strdup (basename));
 	g_ptr_array_add (argv, NULL);
-	ret = g_spawn_sync ("/tmp",
+	ret = g_spawn_sync (tmpdir,
 			    (gchar **) argv->pdata,
 			    NULL,
 			    0,
@@ -244,7 +250,7 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 	if (!g_file_load_contents (output_file, NULL, &data, &len, NULL, error))
 		return FALSE;
 
-	/* open /tmp/$basename.icc as hProfile */
+	/* open $tmpdir/$basename.icc as hProfile */
 	priv->lcms_profile = cmsOpenProfileFromMemTHR (cd_icc_get_context (priv->icc),
 						       data, len);
 	if (priv->lcms_profile == NULL) {
@@ -259,12 +265,11 @@ cd_util_create_colprof (CdUtilPrivate *priv,
 		return FALSE;
 	if (!g_file_delete (ti3_file, NULL, error))
 		return FALSE;
+	if (!g_file_delete (tmpdir_file, NULL, error))
+		return FALSE;
 	return TRUE;
 }
 
-/**
- * cd_util_create_named_color:
- **/
 static gboolean
 cd_util_create_named_color (CdUtilPrivate *priv,
 			    CdDom *dom,
@@ -338,9 +343,6 @@ out:
 	return ret;
 }
 
-/**
- * cd_util_create_x11_gamma:
- **/
 static gboolean
 cd_util_create_x11_gamma (CdUtilPrivate *priv,
 			  CdDom *dom,
@@ -397,13 +399,8 @@ cd_util_create_x11_gamma (CdUtilPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_util_build_srgb_gamma:
- *
- * Values taken from lcms2.
- **/
 static cmsToneCurve *
-cd_util_build_srgb_gamma (void)
+cd_util_build_srgb_gamma (CdUtilPrivate *priv)
 {
 	cmsFloat64Number params[5];
 	params[0] = 2.4;
@@ -411,14 +408,11 @@ cd_util_build_srgb_gamma (void)
 	params[2] = 0.055 / 1.055;
 	params[3] = 1. / 12.92;
 	params[4] = 0.04045;
-	return cmsBuildParametricToneCurve (NULL, 4, params);
+	return cmsBuildParametricToneCurve (cd_icc_get_context (priv->icc), 4, params);
 }
 
-/**
- * cd_util_build_lstar_gamma:
- **/
 static cmsToneCurve *
-cd_util_build_lstar_gamma (void)
+cd_util_build_lstar_gamma (CdUtilPrivate *priv)
 {
 	cmsFloat64Number params[5];
 	params[0] = 3.000000;
@@ -426,14 +420,11 @@ cd_util_build_lstar_gamma (void)
 	params[2] = 0.137924;
 	params[3] = 0.110703;
 	params[4] = 0.080002;
-	return cmsBuildParametricToneCurve (NULL, 4, params);
+	return cmsBuildParametricToneCurve (cd_icc_get_context (priv->icc), 4, params);
 }
 
-/**
- * cd_util_build_rec709_gamma:
- **/
 static cmsToneCurve *
-cd_util_build_rec709_gamma (void)
+cd_util_build_rec709_gamma (CdUtilPrivate *priv)
 {
 	cmsFloat64Number params[5];
 	params[0] = 1.0 / 0.45;
@@ -441,12 +432,10 @@ cd_util_build_rec709_gamma (void)
 	params[2] = 0.099;
 	params[3] = 4.500;
 	params[4] = 0.018;
-	return cmsBuildParametricToneCurve (NULL, LCMS_CURVE_PLUGIN_TYPE_REC709, params);
+	return cmsBuildParametricToneCurve (cd_icc_get_context (priv->icc),
+					    LCMS_CURVE_PLUGIN_TYPE_REC709, params);
 }
 
-/**
- * cd_util_create_standard_space:
- **/
 static gboolean
 cd_util_create_standard_space (CdUtilPrivate *priv,
 			       CdDom *dom,
@@ -471,15 +460,15 @@ cd_util_create_standard_space (CdUtilPrivate *priv,
 	}
 	data = cd_dom_get_node_data (tmp);
 	if (g_strcmp0 (data, "sRGB") == 0) {
-		transfer[0] = cd_util_build_srgb_gamma ();
+		transfer[0] = cd_util_build_srgb_gamma (priv);
 		transfer[1] = transfer[0];
 		transfer[2] = transfer[0];
 	} else if (g_strcmp0 (data, "L*") == 0) {
-		transfer[0] = cd_util_build_lstar_gamma ();
+		transfer[0] = cd_util_build_lstar_gamma (priv);
 		transfer[1] = transfer[0];
 		transfer[2] = transfer[0];
 	} else if (g_strcmp0 (data, "Rec709") == 0) {
-		transfer[0] = cd_util_build_rec709_gamma ();
+		transfer[0] = cd_util_build_rec709_gamma (priv);
 		transfer[1] = transfer[0];
 		transfer[2] = transfer[0];
 	} else {
@@ -495,6 +484,13 @@ cd_util_create_standard_space (CdUtilPrivate *priv,
 		transfer[1] = transfer[0];
 		transfer[2] = transfer[0];
 	}
+	if (transfer[0] == NULL) {
+		ret = FALSE;
+		g_set_error (error, 1, 0,
+			     "failed to set transfer function for %s",
+			     data);
+		goto out;
+	}
 
 	/* values taken from https://en.wikipedia.org/wiki/Standard_illuminant */
 	tmp = cd_dom_get_node (dom, root, "whitepoint");
@@ -576,15 +572,18 @@ cd_util_create_standard_space (CdUtilPrivate *priv,
 						     &white,
 						     &primaries,
 						     transfer);
+	if (priv->lcms_profile == NULL) {
+		ret = FALSE;
+		g_set_error_literal (error, 1, 0,
+				     "Failed to create profile");
+		goto out;
+	}
 	ret = TRUE;
 out:
 	cmsFreeToneCurve (transfer[0]);
 	return ret;
 }
 
-/**
- * cd_util_create_temperature:
- **/
 static gboolean
 cd_util_create_temperature (CdUtilPrivate *priv,
 			    CdDom *dom,
@@ -654,9 +653,6 @@ cd_util_create_temperature (CdUtilPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_util_icc_set_metadata_coverage:
- **/
 static gboolean
 cd_util_icc_set_metadata_coverage (CdIcc *icc, GError **error)
 {
@@ -685,9 +681,6 @@ cd_util_icc_set_metadata_coverage (CdIcc *icc, GError **error)
 	return TRUE;
 }
 
-/**
- * cd_util_create_from_xml:
- **/
 static gboolean
 cd_util_create_from_xml (CdUtilPrivate *priv,
 			 const gchar *filename,
@@ -791,9 +784,6 @@ cd_util_create_from_xml (CdUtilPrivate *priv,
 	return TRUE;
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char **argv)
 {
