@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 #include <locale.h>
 
-#ifdef HAVE_LIBSYSTEMD_LOGIN
+#ifdef HAVE_SYSTEMD
 #include <systemd/sd-login.h>
 #endif
 
@@ -44,9 +44,10 @@
 #include "cd-profile-db.h"
 #include "cd-profile.h"
 #include "cd-icc-store.h"
-#include "cd-resources.h"
 #include "cd-sensor-client.h"
 
+#include "colord-resources.h"
+
 typedef struct {
 	GDBusConnection		*connection;
 	GDBusNodeInfo		*introspection_daemon;
@@ -59,11 +60,8 @@ typedef struct {
 	CdMappingDb		*mapping_db;
 	CdDeviceDb		*device_db;
 	CdProfileDb		*profile_db;
-#ifdef HAVE_UDEV
 	CdSensorClient		*sensor_client;
-#endif
 	GPtrArray		*sensors;
-	GHashTable		*standard_spaces;
 	GPtrArray		*plugins;
 	GMainLoop		*loop;
 	gboolean		 create_dummy_sensor;
@@ -72,9 +70,6 @@ typedef struct {
 	gchar			*system_model;
 } CdMainPrivate;
 
-/**
- * cd_main_profile_removed:
- **/
 static void
 cd_main_profile_removed (CdMainPrivate *priv, CdProfile *profile)
 {
@@ -118,9 +113,6 @@ cd_main_profile_removed (CdMainPrivate *priv, CdProfile *profile)
 				       NULL);
 }
 
-/**
- * cd_main_profile_invalidate_cb:
- **/
 static void
 cd_main_profile_invalidate_cb (CdProfile *profile,
 			       gpointer user_data)
@@ -132,9 +124,6 @@ cd_main_profile_invalidate_cb (CdProfile *profile,
 	cd_main_profile_removed (priv, profile);
 }
 
-/**
- * cd_main_device_removed:
- **/
 static void
 cd_main_device_removed (CdMainPrivate *priv, CdDevice *device)
 {
@@ -173,9 +162,6 @@ cd_main_device_removed (CdMainPrivate *priv, CdDevice *device)
 				       &error);
 }
 
-/**
- * cd_main_device_invalidate_cb:
- **/
 static void
 cd_main_device_invalidate_cb (CdDevice *device,
 			      gpointer user_data)
@@ -187,9 +173,6 @@ cd_main_device_invalidate_cb (CdDevice *device,
 	cd_main_device_removed (priv, device);
 }
 
-/**
- * cd_main_add_profile:
- **/
 static gboolean
 cd_main_add_profile (CdMainPrivate *priv,
 		     CdProfile *profile,
@@ -206,9 +189,6 @@ cd_main_add_profile (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_create_profile:
- **/
 static CdProfile *
 cd_main_create_profile (CdMainPrivate *priv,
 			const gchar *sender,
@@ -261,9 +241,6 @@ cd_main_create_profile (CdMainPrivate *priv,
 	return g_object_ref (profile_tmp);
 }
 
-/**
- * cd_main_auto_add_from_md:
- **/
 static gboolean
 cd_main_auto_add_from_md (CdMainPrivate *priv,
 			  CdDevice *device,
@@ -321,9 +298,6 @@ cd_main_auto_add_from_md (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_auto_add_from_db:
- **/
 static gboolean
 cd_main_auto_add_from_db (CdMainPrivate *priv,
 			  CdDevice *device,
@@ -361,9 +335,6 @@ cd_main_auto_add_from_db (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_device_auto_add_from_md:
- **/
 static void
 cd_main_device_auto_add_from_md (CdMainPrivate *priv,
 				 CdDevice *device)
@@ -385,9 +356,6 @@ cd_main_device_auto_add_from_md (CdMainPrivate *priv,
 	}
 }
 
-/**
- * cd_main_device_auto_add_from_db:
- **/
 static void
 cd_main_device_auto_add_from_db (CdMainPrivate *priv, CdDevice *device)
 {
@@ -444,9 +412,6 @@ cd_main_device_auto_add_from_db (CdMainPrivate *priv, CdDevice *device)
 	}
 }
 
-/**
- * cd_main_device_register_on_bus:
- **/
 static gboolean
 cd_main_device_register_on_bus (CdMainPrivate *priv,
 				CdDevice *device,
@@ -474,9 +439,6 @@ cd_main_device_register_on_bus (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_device_add:
- **/
 static gboolean
 cd_main_device_add (CdMainPrivate *priv,
 		    CdDevice *device,
@@ -518,14 +480,11 @@ cd_main_device_add (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_get_seat_for_process:
- */
 static gchar *
 cd_main_get_seat_for_process (guint pid)
 {
 	gchar *seat = NULL;
-#ifdef HAVE_LIBSYSTEMD_LOGIN
+#ifdef HAVE_SYSTEMD
 	char *sd_seat = NULL;
 	char *sd_session = NULL;
 	gint rc;
@@ -553,9 +512,6 @@ out:
 	return seat;
 }
 
-/**
- * cd_main_create_device:
- **/
 static CdDevice *
 cd_main_create_device (CdMainPrivate *priv,
 		       const gchar *sender,
@@ -594,9 +550,6 @@ cd_main_create_device (CdMainPrivate *priv,
 	return g_object_ref (device_tmp);
 }
 
-/**
- * cd_main_device_array_to_variant:
- **/
 static GVariant *
 cd_main_device_array_to_variant (GPtrArray *array, guint uid)
 {
@@ -630,9 +583,6 @@ cd_main_device_array_to_variant (GPtrArray *array, guint uid)
 				    length);
 }
 
-/**
- * cd_main_profile_array_to_variant:
- **/
 static GVariant *
 cd_main_profile_array_to_variant (GPtrArray *array)
 {
@@ -656,9 +606,6 @@ cd_main_profile_array_to_variant (GPtrArray *array)
 				    length);
 }
 
-/**
- * cd_main_sensor_array_to_variant:
- **/
 static GVariant *
 cd_main_sensor_array_to_variant (GPtrArray *array)
 {
@@ -682,9 +629,6 @@ cd_main_sensor_array_to_variant (GPtrArray *array)
 				    length);
 }
 
-/**
- * cd_main_profile_auto_add_from_db:
- **/
 static void
 cd_main_profile_auto_add_from_db (CdMainPrivate *priv,
 				  CdProfile *profile)
@@ -728,9 +672,6 @@ cd_main_profile_auto_add_from_db (CdMainPrivate *priv,
 	}
 }
 
-/**
- * cd_main_profile_auto_add_from_md:
- **/
 static void
 cd_main_profile_auto_add_from_md (CdMainPrivate *priv,
 				  CdProfile *profile)
@@ -758,9 +699,6 @@ typedef enum {
 	CD_LOGGING_FLAG_LAST
 } CdLoggingFlags;
 
-/**
- * cd_main_profile_register_on_bus:
- **/
 static gboolean
 cd_main_profile_register_on_bus (CdMainPrivate *priv,
 				 CdProfile *profile,
@@ -790,23 +728,6 @@ cd_main_profile_register_on_bus (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_get_standard_space_override:
- **/
-static CdProfile *
-cd_main_get_standard_space_override (CdMainPrivate *priv,
-				     const gchar *standard_space)
-{
-	CdProfile *profile;
-	profile = g_hash_table_lookup (priv->standard_spaces, standard_space);
-	if (profile == NULL)
-		return NULL;
-	return g_object_ref (profile);
-}
-
-/**
- * cd_main_get_standard_space_metadata:
- **/
 static CdProfile *
 cd_main_get_standard_space_metadata (CdMainPrivate *priv,
 				     const gchar *standard_space)
@@ -839,9 +760,6 @@ cd_main_get_standard_space_metadata (CdMainPrivate *priv,
 	return g_object_ref (profile_best);
 }
 
-/**
- * cd_main_get_display_fallback_id:
- **/
 static gchar *
 cd_main_get_display_fallback_id (GVariant *dict)
 {
@@ -864,9 +782,6 @@ cd_main_get_display_fallback_id (GVariant *dict)
 	return device_id;
 }
 
-/**
- * cd_main_get_cmdline_for_pid:
- **/
 static gchar *
 cd_main_get_cmdline_for_pid (guint pid)
 {
@@ -899,9 +814,6 @@ cd_main_get_cmdline_for_pid (guint pid)
 	return cmdline;
 }
 
-/**
- * cd_main_daemon_method_call:
- **/
 static void
 cd_main_daemon_method_call (GDBusConnection *connection, const gchar *sender,
 			    const gchar *object_path, const gchar *interface_name,
@@ -1148,10 +1060,8 @@ cd_main_daemon_method_call (GDBusConnection *connection, const gchar *sender,
 		g_debug ("CdMain: %s:GetStandardSpace(%s)",
 			 sender, device_id);
 
-		/* first search overrides */
-		profile = cd_main_get_standard_space_override (priv, device_id);
-		if (profile == NULL)
-			profile = cd_main_get_standard_space_metadata (priv, device_id);
+		/* will also return overrides */
+		profile = cd_main_get_standard_space_metadata (priv, device_id);
 		if (profile == NULL) {
 			g_dbus_method_invocation_return_error (invocation,
 							       CD_CLIENT_ERROR,
@@ -1643,9 +1553,6 @@ cd_main_daemon_method_call (GDBusConnection *connection, const gchar *sender,
 	g_critical ("failed to process method %s", method_name);
 }
 
-/**
- * cd_main_daemon_get_property:
- **/
 static GVariant *
 cd_main_daemon_get_property (GDBusConnection *connection_, const gchar *sender,
 			     const gchar *object_path, const gchar *interface_name,
@@ -1670,9 +1577,6 @@ cd_main_daemon_get_property (GDBusConnection *connection_, const gchar *sender,
 	return NULL;
 }
 
-/**
- * cd_main_on_bus_acquired_cb:
- **/
 static void
 cd_main_on_bus_acquired_cb (GDBusConnection *connection,
 			    const gchar *name,
@@ -1697,9 +1601,6 @@ cd_main_on_bus_acquired_cb (GDBusConnection *connection,
 	g_assert (registration_id > 0);
 }
 
-/**
- * cd_main_icc_store_added_cb:
- **/
 static void
 cd_main_icc_store_added_cb (CdIccStore *icc_store,
 			    CdIcc *icc,
@@ -1758,9 +1659,6 @@ cd_main_icc_store_added_cb (CdIccStore *icc_store,
 	}
 }
 
-/**
- * cd_main_icc_store_removed_cb:
- **/
 static void
 cd_main_icc_store_removed_cb (CdIccStore *icc_store,
 			      CdIcc *icc,
@@ -1778,9 +1676,6 @@ cd_main_icc_store_removed_cb (CdIccStore *icc_store,
 	cd_profile_array_remove (priv->profiles_array, profile);
 }
 
-/**
- * cd_main_add_disk_device:
- **/
 static void
 cd_main_add_disk_device (CdMainPrivate *priv, const gchar *device_id)
 {
@@ -1852,9 +1747,6 @@ cd_main_add_disk_device (CdMainPrivate *priv, const gchar *device_id)
 	}
 }
 
-/**
- * cd_main_sensor_register_on_bus:
- **/
 static gboolean
 cd_main_sensor_register_on_bus (CdMainPrivate *priv,
 				CdSensor *sensor,
@@ -1882,9 +1774,6 @@ cd_main_sensor_register_on_bus (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_add_sensor:
- **/
 static void
 cd_main_add_sensor (CdMainPrivate *priv, CdSensor *sensor)
 {
@@ -1910,9 +1799,6 @@ cd_main_add_sensor (CdMainPrivate *priv, CdSensor *sensor)
 	}
 }
 
-/**
- * cd_main_plugin_phase:
- **/
 static void
 cd_main_plugin_phase (CdMainPrivate *priv, CdPluginPhase phase)
 {
@@ -1958,9 +1844,6 @@ cd_main_plugin_phase (CdMainPrivate *priv, CdPluginPhase phase)
 	}
 }
 
-/**
- * cd_main_on_name_acquired_cb:
- **/
 static void
 cd_main_on_name_acquired_cb (GDBusConnection *connection,
 			     const gchar *name,
@@ -2021,10 +1904,8 @@ cd_main_on_name_acquired_cb (GDBusConnection *connection,
 		cd_main_add_disk_device (priv, device_id);
 	}
 
-#ifdef HAVE_UDEV
 	/* add sensor devices */
 	cd_sensor_client_coldplug (priv->sensor_client);
-#endif
 
 	/* coldplug plugin devices */
 	cd_main_plugin_phase (priv, CD_PLUGIN_PHASE_COLDPLUG);
@@ -2044,9 +1925,6 @@ cd_main_on_name_acquired_cb (GDBusConnection *connection,
 	}
 }
 
-/**
- * cd_main_on_name_lost_cb:
- **/
 static void
 cd_main_on_name_lost_cb (GDBusConnection *connection,
 			 const gchar *name,
@@ -2057,11 +1935,7 @@ cd_main_on_name_lost_cb (GDBusConnection *connection,
 	g_main_loop_quit (priv->loop);
 }
 
-#ifdef HAVE_UDEV
 
-/**
- * cd_main_client_sensor_added_cb:
- **/
 static void
 cd_main_client_sensor_added_cb (CdSensorClient *sensor_client_,
 				CdSensor *sensor,
@@ -2071,9 +1945,6 @@ cd_main_client_sensor_added_cb (CdSensorClient *sensor_client_,
 	cd_main_add_sensor (priv, sensor);
 }
 
-/**
- * cd_main_client_sensor_removed_cb:
- **/
 static void
 cd_main_client_sensor_removed_cb (CdSensorClient *sensor_client_,
 				  CdSensor *sensor,
@@ -2095,11 +1966,7 @@ cd_main_client_sensor_removed_cb (CdSensorClient *sensor_client_,
 				       NULL);
 	g_ptr_array_remove (priv->sensors, sensor);
 }
-#endif
 
-/**
- * cd_main_timed_exit_cb:
- **/
 static gboolean
 cd_main_timed_exit_cb (gpointer user_data)
 {
@@ -2108,9 +1975,6 @@ cd_main_timed_exit_cb (gpointer user_data)
 	return G_SOURCE_REMOVE;
 }
 
-/**
- * cd_main_load_introspection:
- **/
 static GDBusNodeInfo *
 cd_main_load_introspection (const gchar *filename, GError **error)
 {
@@ -2130,9 +1994,6 @@ cd_main_load_introspection (const gchar *filename, GError **error)
 	return g_dbus_node_info_new_for_xml (g_bytes_get_data (data, NULL), error);
 }
 
-/**
- * cd_main_plugin_free:
- **/
 static void
 cd_main_plugin_free (CdPlugin *plugin)
 {
@@ -2141,9 +2002,6 @@ cd_main_plugin_free (CdPlugin *plugin)
 	g_free (plugin);
 }
 
-/**
- * cd_main_plugin_device_added:
- **/
 static void
 cd_main_plugin_device_added_cb (CdPlugin *plugin,
 				CdDevice *device,
@@ -2170,9 +2028,6 @@ cd_main_plugin_device_added_cb (CdPlugin *plugin,
 	}
 }
 
-/**
- * cd_main_plugin_device_removed_cb:
- **/
 static void
 cd_main_plugin_device_removed_cb (CdPlugin *plugin,
 				  CdDevice *device,
@@ -2183,9 +2038,6 @@ cd_main_plugin_device_removed_cb (CdPlugin *plugin,
 	cd_main_device_removed (priv, device);
 }
 
-/**
- * cd_main_load_plugin:
- */
 static gboolean
 cd_main_load_plugin (CdMainPrivate *priv,
 		     const gchar *filename,
@@ -2249,9 +2101,6 @@ cd_main_load_plugin (CdMainPrivate *priv,
 	return TRUE;
 }
 
-/**
- * cd_main_load_plugins:
- */
 static void
 cd_main_load_plugins (CdMainPrivate *priv)
 {
@@ -2300,9 +2149,6 @@ cd_main_load_plugins (CdMainPrivate *priv)
 	} while (TRUE);
 }
 
-/**
- * cd_main_get_edid_for_output:
- **/
 static CdEdid *
 cd_main_get_edid_for_output (const gchar *output_name)
 {
@@ -2356,9 +2202,6 @@ cd_main_get_edid_for_output (const gchar *output_name)
 	return g_object_ref (edid);
 }
 
-/**
- * cd_main_get_display_id:
- **/
 static gchar *
 cd_main_get_display_id (CdEdid *edid)
 {
@@ -2374,9 +2217,6 @@ cd_main_get_display_id (CdEdid *edid)
 	return g_string_free (device_id, FALSE);
 }
 
-/**
- * cd_main_check_duplicate_edids:
- **/
 static gboolean
 cd_main_check_duplicate_edids (void)
 {
@@ -2412,9 +2252,6 @@ cd_main_check_duplicate_edids (void)
 	return use_xrandr_mode;
 }
 
-/**
- * cd_main_dmi_get_from_filename:
- **/
 static gchar *
 cd_main_dmi_get_from_filename (const gchar *filename)
 {
@@ -2446,9 +2283,6 @@ cd_main_dmi_get_from_filename (const gchar *filename)
 	return data;
 }
 
-/**
- * cd_main_dmi_get_from_filenames:
- **/
 static gchar *
 cd_main_dmi_get_from_filenames (const gchar * const * filenames)
 {
@@ -2465,9 +2299,6 @@ cd_main_dmi_get_from_filenames (const gchar * const * filenames)
 }
 
 
-/**
- * cd_main_dmi_get_vendor:
- **/
 static gchar *
 cd_main_dmi_get_vendor (void)
 {
@@ -2484,9 +2315,6 @@ cd_main_dmi_get_vendor (void)
 		return g_strdup("Unknown");
 	return cd_quirk_vendor_name (tmp);
 }
-/**
- * cd_main_dmi_get_model:
- **/
 static gchar *
 cd_main_dmi_get_model (void)
 {
@@ -2509,9 +2337,6 @@ cd_main_dmi_get_model (void)
 	return model;
 }
 
-/**
- * cd_main_dmi_setup:
- **/
 static void
 cd_main_dmi_setup (CdMainPrivate *priv)
 {
@@ -2519,9 +2344,6 @@ cd_main_dmi_setup (CdMainPrivate *priv)
 	priv->system_model = cd_main_dmi_get_model ();
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char *argv[])
 {
@@ -2573,11 +2395,6 @@ main (int argc, char *argv[])
 	priv->devices_array = cd_device_array_new ();
 	priv->profiles_array = cd_profile_array_new ();
 	priv->sensors = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	priv->standard_spaces = g_hash_table_new_full (g_str_hash,
-						 g_str_equal,
-						 g_free,
-						 (GDestroyNotify) g_object_unref);
-#ifdef HAVE_UDEV
 	priv->sensor_client = cd_sensor_client_new ();
 	g_signal_connect (priv->sensor_client, "sensor-added",
 			  G_CALLBACK (cd_main_client_sensor_added_cb),
@@ -2585,7 +2402,6 @@ main (int argc, char *argv[])
 	g_signal_connect (priv->sensor_client, "sensor-removed",
 			  G_CALLBACK (cd_main_client_sensor_removed_cb),
 			  priv);
-#endif
 
 	/* connect to the mapping db */
 	priv->mapping_db = cd_mapping_db_new ();
@@ -2708,11 +2524,8 @@ out:
 			g_ptr_array_unref (priv->sensors);
 		if (priv->plugins != NULL)
 			g_ptr_array_unref (priv->plugins);
-		g_hash_table_destroy (priv->standard_spaces);
-#ifdef HAVE_UDEV
 		if (priv->sensor_client != NULL)
 			g_object_unref (priv->sensor_client);
-#endif
 		if (priv->icc_store != NULL)
 			g_object_unref (priv->icc_store);
 		if (priv->mapping_db != NULL)
